@@ -19,8 +19,10 @@ Usage::
     list_servers_paginator: ListServersPaginator = client.get_paginator("list_servers")
     ```
 """
-from mypy_boto3_transfer.client import TransferClient as Client, TransferClient
+from mypy_boto3_transfer.client import TransferClient
 from mypy_boto3_transfer.paginator import ListServersPaginator
 
+Client = TransferClient
+
 
 __all__ = ("Client", "ListServersPaginator", "TransferClient")
